@@ -8,7 +8,8 @@ from datetime import datetime, date
 class BoletoItau( BoletoData ):   
     '''
         Gera Dados necessários para criação de boleto para o banco Itau
-        com registro
+        Todas as carteiras com excessão das que utilizam 15 dígitos: (106,107,
+        195,196,198)
     '''
     def __init__(self, *args, **kwargs):
 
